@@ -47,6 +47,11 @@ free_operation_spec (OperationSpec *os)
   g_clear_pointer (&os->string, g_free);
   g_clear_object (&os->options);
 
+  if (os->cancellable) {
+    g_cancellable_cancel (os->cancellable);
+    g_clear_object (&os->cancellable);
+  }
+
   if (os->keys)
     g_list_free (os->keys);
 
@@ -667,13 +672,43 @@ grl_lua_operations_get_current_op (lua_State *L)
     /* Source State is finalized. At this state it should be waiting the
      * watchdog to free its data. Only a broken source would request
      * OperationSpec on FINALIZED State */
-    GRL_WARNING ("operation-id: %u is on FINALIZED state and cannot be changed",
-                 os->operation_id);
+    GRL_DEBUG ("The grilo operation ended when grl.callback() was called. "
+               "No current operation for op-id: %u", os->operation_id);
     return NULL;
   }
   return os;
 }
 
+void
+grl_lua_operations_cancel_operation (lua_State *L,
+                                     guint operation_id)
+{
+    OperationSpec *os, *current_os;
+    LuaSourceState state;
+
+    os = priv_state_operations_source_get_op_data (L, operation_id);
+    g_return_if_fail (os != NULL);
+
+    state = priv_state_operations_source_get_state (L, operation_id);
+    if (state != LUA_SOURCE_WAITING) {
+      GRL_DEBUG ("Can't cancel operation (%u) on source (%s) with as state is: %s",
+                 operation_id, grl_source_get_id (os->source),
+                 source_op_state_str[state]);
+      return;
+    }
+
+    /* All async operations on lua-library should verify os->cancellable to
+     * proper handling the cancelation of ongoing operation */
+    g_cancellable_cancel (os->cancellable);
+
+    current_os = priv_state_current_op_get_op_data (L);
+
+    priv_state_operations_remove_source_state (L, os->operation_id);
+    if (current_os != NULL && current_os->operation_id == os->operation_id)
+      priv_state_current_op_remove (L);
+    free_operation_spec (os);
+}
+
 /*
  * This is a wrapper to do execute the lua_pcall and all internals that might
  * be necessary to Lua-Library before calling the Lua function. The stack
@@ -686,7 +721,11 @@ grl_lua_operations_pcall (lua_State *L,
                           OperationSpec *os,
                           GError **err)
 {
+  gint ret;
+
   g_assert_nonnull (os);
+  g_assert_nonnull (err);
+  g_assert_null (*err);
 
   GRL_DEBUG ("%s | %s (op-id: %u)", __func__,
              grl_source_get_id (os->source),
@@ -699,16 +738,20 @@ grl_lua_operations_pcall (lua_State *L,
 
   watchdog_operation_push (L, os->operation_id);
   grl_lua_operations_set_source_state (L, LUA_SOURCE_RUNNING, os);
-  if (lua_pcall (L, nargs + 1, 0, 0)) {
-    *err = g_error_new_literal (GRL_CORE_ERROR,
-                                os->error_code,
-                                lua_tolstring (L, -1, NULL));
+
+  ret = lua_pcall (L, nargs + 1, 0, 0);
+  if (ret != LUA_OK) {
+    const gchar *msg = lua_tolstring (L, -1, NULL);
     lua_pop (L, 1);
+
+    GRL_DEBUG ("lua_pcall failed: due %s (err %d)", msg, ret);
+    *err = g_error_new_literal (GRL_CORE_ERROR, os->error_code, msg);
+    grl_lua_operations_set_source_state (L, LUA_SOURCE_FINALIZED, os);
   }
 
   lua_gc (L, LUA_GCCOLLECT, 0);
   lua_gc (L, LUA_GCRESTART, 0);
-  return (*err == NULL);
+  return (ret == LUA_OK);
 }
 
 /*
