@@ -53,6 +53,7 @@ typedef struct {
   guint num_urls;
   gboolean is_table;
   gchar **results;
+  GCancellable *cancellable;
   OperationSpec *os;
 } FetchOperation;
 
@@ -62,9 +63,12 @@ typedef struct {
   gint lua_callback;
   gchar *url;
   gchar **filenames;
+  GCancellable *cancellable;
   OperationSpec *os;
 } UnzipOperation;
 
+static gpointer grl_lua_library_load_goa_data (lua_State *L);
+
 /* ================== Lua-Library utils/helpers ============================ */
 
 static gchar *
@@ -477,6 +481,10 @@ grl_util_fetch_done (GObject *source_object,
 
   if (!grl_net_wc_request_finish (GRL_NET_WC (source_object),
                                   res, &data, &len, &err)) {
+    if (g_error_matches (err, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
+      GRL_DEBUG ("fetch operation was cancelled");
+      goto free_fetch_op;
+    }
     data = NULL;
   } else if (!g_utf8_validate(data, len, NULL)) {
     fixed = g_convert (data, len, "UTF-8", "ISO8859-1", NULL, NULL, NULL);
@@ -494,7 +502,7 @@ grl_util_fetch_done (GObject *source_object,
 
   if (err != NULL) {
     GRL_WARNING ("Can't fetch element %d (URL: %s): '%s'", fo->index + 1, fo->url, err->message);
-    g_error_free (err);
+    g_clear_error (&err);
   } else {
     GRL_DEBUG ("fetch_done element %d of %d urls", fo->index + 1, fo->num_urls);
   }
@@ -530,10 +538,12 @@ grl_util_fetch_done (GObject *source_object,
   if (!grl_lua_operations_pcall (L, 2, os, &err)) {
     if (err != NULL) {
       GRL_WARNING ("calling source callback function fail: %s", err->message);
-      g_error_free (err);
+      g_clear_error (&err);
     }
   }
 
+free_fetch_op:
+  g_object_unref (fo->cancellable);
   luaL_unref (L, LUA_REGISTRYINDEX, fo->lua_userdata);
   luaL_unref (L, LUA_REGISTRYINDEX, fo->lua_callback);
 
@@ -636,13 +646,16 @@ grl_util_unzip_done (GObject *source_object,
   OperationSpec *os = uo->os;
   char **results;
 
-  grl_net_wc_request_finish (GRL_NET_WC (source_object),
-                             res, &data, &len, &err);
-
-  if (err != NULL) {
+  if (!grl_net_wc_request_finish (GRL_NET_WC (source_object),
+                                  res, &data, &len, &err)) {
     guint len, i;
-    GRL_WARNING ("Can't fetch zip file (URL: %s): '%s'", uo->url, err->message);
-    g_error_free (err);
+    if (g_error_matches (err, GRL_NET_WC_ERROR, GRL_NET_WC_ERROR_CANCELLED)) {
+      GRL_DEBUG ("unzip operation was cancelled");
+      goto free_unzip_op;
+    } else if (err != NULL) {
+      GRL_WARNING ("Can't fetch zip file (URL: %s): '%s'", uo->url, err->message);
+      g_error_free (err);
+    }
     len = g_strv_length (uo->filenames);
     results = g_new0 (gchar *, len + 1);
     for (i = 0; i < len; i++)
@@ -672,11 +685,12 @@ grl_util_unzip_done (GObject *source_object,
     }
   }
 
-  luaL_unref (L, LUA_REGISTRYINDEX, uo->lua_userdata);
-  luaL_unref (L, LUA_REGISTRYINDEX, uo->lua_callback);
-
   g_strfreev (results);
 
+free_unzip_op:
+  g_object_unref (uo->cancellable);
+  luaL_unref (L, LUA_REGISTRYINDEX, uo->lua_userdata);
+  luaL_unref (L, LUA_REGISTRYINDEX, uo->lua_callback);
   g_strfreev (uo->filenames);
   g_free (uo->url);
   g_free (uo);
@@ -744,7 +758,13 @@ grl_l_operation_get_options (lua_State *L)
   luaL_argcheck (L, lua_isstring (L, 1), 1, "expecting option (string)");
 
   os = grl_lua_operations_get_current_op (L);
-  g_return_val_if_fail (os != NULL, 0);
+  if (os == NULL) {
+    luaL_error (L, "grl.get_options() failed: Can't retrieve current operation. "
+                   "Source is broken as grl.callback() has been called but source "
+                   "is still active");
+    return 0;
+  }
+
   option = lua_tostring (L, 1);
 
   if (g_strcmp0 (option, "type") == 0) {
@@ -891,7 +911,7 @@ grl_l_operation_get_options (lua_State *L)
 }
 
 /**
-* grl.get_media_keys
+* grl.get_requested_keys
 *
 * @return: array of all requested keys from application (may be empty);
 */
@@ -903,7 +923,12 @@ grl_l_operation_get_keys (lua_State *L)
   GList *it;
 
   os = grl_lua_operations_get_current_op (L);
-  g_return_val_if_fail (os != NULL, 0);
+  if (os == NULL) {
+    luaL_error (L, "grl.get_requested_keys() failed: Can't retrieve current operation. "
+                   "Source is broken as grl.callback() has been called but source "
+                   "is still active");
+    return 0;
+  }
 
   registry = grl_registry_get_default ();
   lua_newtable (L);
@@ -1031,6 +1056,12 @@ grl_l_media_get_keys (lua_State *L)
   GrlMedia *media;
 
   os = grl_lua_operations_get_current_op (L);
+  if (os == NULL) {
+    luaL_error (L, "grl.get_media_keys() failed: Can't retrieve current operation. "
+                   "Source is broken as grl.callback() has been called but source "
+                   "is still active");
+    return 0;
+  }
   media = os->media;
 
   if (media == NULL) {
@@ -1089,7 +1120,7 @@ grl_l_media_get_keys (lua_State *L)
 /**
 * grl.fetch
 *
-* @url: (string or array) The http url to GET the content.
+* @url: (string or array) The http URL(s) to GET the content.
 * @netopts: [optional] (table) Options to set the GrlNetWc object.
 * @callback: (function) The function to be called after fetch is complete.
 * @userdata: [optional] User data to be passed to the @callback.
@@ -1118,6 +1149,12 @@ grl_l_fetch (lua_State *L)
                  "expecting callback function after network parameters");
 
   os = grl_lua_operations_get_current_op (L);
+  if (os == NULL) {
+    luaL_error (L, "grl.fetch() failed: Can't retrieve current operation. "
+                   "Source is broken as grl.callback() has been called but source "
+                   "is still active");
+    return 0;
+  }
 
   /* keep arguments aligned */
   if (lua_isfunction (L, 2)) {
@@ -1179,6 +1216,7 @@ grl_l_fetch (lua_State *L)
     fo = g_new0 (FetchOperation, 1);
     fo->L = L;
     fo->os = os;
+    fo->cancellable = g_object_ref (os->cancellable);
     fo->lua_userdata = lua_userdata;
     fo->lua_callback = lua_callback;
     fo->index = i;
@@ -1187,7 +1225,7 @@ grl_l_fetch (lua_State *L)
     fo->is_table = is_table;
     fo->results = results;
 
-    grl_net_wc_request_async (wc, urls[i], NULL, grl_util_fetch_done, fo);
+    grl_net_wc_request_async (wc, urls[i], os->cancellable, grl_util_fetch_done, fo);
   }
   g_object_unref (wc);
   g_free (urls);
@@ -1217,8 +1255,9 @@ grl_l_callback (lua_State *L)
   nparam = lua_gettop (L);
   os = grl_lua_operations_get_current_op (L);
   if (os == NULL) {
-    luaL_error (L, "Source is broken as callback was called "
-                "after the operation has been finalized");
+    luaL_error (L, "grl.callback() failed: Can't retrieve current operation. "
+                   "Source is broken as grl.callback() has been called but source "
+                   "is still active");
     return 0;
   }
 
@@ -1444,18 +1483,25 @@ grl_l_unzip (lua_State *L)
   }
   GRL_DEBUG ("grl.unzip() -> '%s'", url);
 
-  wc = net_wc_new_with_options (L, 3);
   os = grl_lua_operations_get_current_op (L);
+  if (os == NULL) {
+    luaL_error (L, "grl.unzip() failed: Can't retrieve current operation. "
+                   "Source is broken as grl.callback() has been called but source "
+                   "is still active");
+    return 0;
+  }
+  wc = net_wc_new_with_options (L, 3);
 
   uo = g_new0 (UnzipOperation, 1);
   uo->L = L;
+  uo->cancellable = g_object_ref (os->cancellable);
   uo->lua_userdata = lua_userdata;
   uo->lua_callback = lua_callback;
   uo->url = g_strdup (url);
   uo->filenames = filenames;
   uo->os = os;
 
-  grl_net_wc_request_async (wc, url, NULL, grl_util_unzip_done, uo);
+  grl_net_wc_request_async (wc, url, os->cancellable, grl_util_unzip_done, uo);
   g_object_unref (wc);
 
   grl_lua_operations_set_source_state (L, LUA_SOURCE_WAITING, os);
@@ -1698,7 +1744,7 @@ grl_lua_library_save_goa_data (lua_State *L, gpointer goa_object)
  * @L: LuaState where the data is stored.
  * @return: The #GoaObject.
  **/
-gpointer
+static gpointer
 grl_lua_library_load_goa_data (lua_State *L)
 {
 #ifdef GOA_ENABLED
