@@ -45,7 +45,7 @@ netopts = {
 -- Source utils --
 ------------------
 
-METROLYRICS_INVALID_URL_CHARS = "[" .. "%(%)%[%]%$%&" .. "]"
+METROLYRICS_INVALID_URL_CHARS = "[" .. "%(%)%[%]%$%&%%" .. "]"
 METROLYRICS_DEFAULT_QUERY = "http://www.metrolyrics.com/%s-lyrics-%s.html"
 
 ---------------------------------
@@ -66,10 +66,12 @@ function grl_source_resolve()
   -- Prepare artist and title strings to the url
   artist = req.artist:gsub(METROLYRICS_INVALID_URL_CHARS, "")
   artist = artist:gsub("%s+", "-")
+  artist = grl.encode(artist)
   title = req.title:gsub(METROLYRICS_INVALID_URL_CHARS, "")
   title = title:gsub("%s+", "-")
+  title = grl.encode(title)
   url = string.format(METROLYRICS_DEFAULT_QUERY, title, artist)
-  grl.fetch(url, "fetch_page_cb", netopts)
+  grl.fetch(url, fetch_page_cb, netopts)
 end
 
 ---------------
@@ -86,18 +88,19 @@ end
 
 function metrolyrics_get_lyrics(feed)
   local media = {}
-  local lyrics_body = '<div id="lyrics%-body%-text">(.-)</div>'
+  local lyrics_body = '<div id="lyrics%-body%-text".->(.-)</div>'
   local noise_array = {
     { noise = "</p>",  sub = "\n\n" },
     { noise = "<p class='verse'><p class='verse'>",  sub = "\n\n" },
     { noise = "<p class='verse'>",  sub = "" },
     { noise = "<br/>",  sub = "" },
+    { noise = "<br>",  sub = "" },
   }
 
   -- remove html noise
   feed = feed:match(lyrics_body)
   if not feed then
-    grl.warning ("This Lyrics do not match our parser! Please file a bug!")
+    grl.debug ("This Lyrics do not match our parser")
     return nil
   end
 
